==> react-native-component-splitter-0.0.9.tgz: package/README.md <==
<!-- Title -->
<p align="center">
<img src="/src/assets/icon.png" alt="alt text" width="150"/>
</p>

<!-- Header -->

<p align="center">
  <b>Create a React Native sub-component from Component.</b>
  <br />
</p>

<p align="center">
  <img height="450" src="/src/assets/example.gif">
</p>

# React Native Component Splitter

it is a **VS CODE** extension which allows us to split React components into sub-components

# Usage

**1**. Select the code you want to split to a new sub-component.

**2**. Choose `Split Component` from the Right-Click Menu / Command Palette.
or press `alt+option+cmd+k`

**3**. Enter a name for the new sub-component.

# Shortcut keys

| Plateform | Key                  |
| --------- | -------------------- |
| MAC       | **alt+option+cmd+k** |
| Window    | **ctrl+shift+k**     |

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/nomi9995"><img src="https://avatars3.githubusercontent.com/u/36044436?s=460&u=c7471cd9ccec793c7a0fccc7db475a577ff7969d&v=4" width="100px;" alt="Numan"/><br /><sub><b>Numan</b></sub></a><br /><a href="#infra-Numan" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="https://github.com/nomi9995/react-native-bottomsheet-reanimated/commits?author=nomi9995" title="Code">💻</a></td>
  </tr>
</table>

<!-- ALL-CONTRIBUTORS-LIST:END -->

==> react-native-component-splitter-0.0.12.tgz: package/README.md <==
### Would you like to support me?

<a href="https://www.buymeacoffee.com/numan.dev" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

---

<!-- Title -->
<p align="center">
<img src="/src/assets/icon.png" alt="alt text" width="150"/>
</p>

<!-- Header -->

<p align="center">
  <b>Create a React Native sub-component from Component.</b>
  <br />
</p>

<p align="center">
  <img height="450" src="/src/assets/example.gif">
</p>

# React Native Component Splitter

it is a **VS CODE** extension which allows us to split React Native components into sub-components

# Usage

**1**. Select the code you want to split to a new sub-component.

**2**. Choose `Split Component` from the Right-Click Menu / Command Palette.
or press `alt+option+cmd+k`

**3**. Enter a name for the new sub-component.

# Shortcut keys

| Plateform | Key                  |
| --------- | -------------------- |
| MAC       | **alt+option+cmd+k** |
| Window    | **ctrl+shift+k**     |

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/nomi9995"><img src="https://avatars3.githubusercontent.com/u/36044436?s=460&u=c7471cd9ccec793c7a0fccc7db475a577ff7969d&v=4" width="100px;" alt="Numan"/><br /><sub><b>Numan</b></sub></a><br /><a href="#infra-Numan" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="https://github.com/nomi9995/react-native-bottomsheet-reanimated/commits?author=nomi9995" title="Code">💻</a></td>
  </tr>
</table>

<!-- ALL-CONTRIBUTORS-LIST:END -->
